@@ -32,7 +32,7 @@ THE SOFTWARE.
 import numpy as np
 from matplotlib import mpl
 import matplotlib.pyplot as plt
-import EMMSA.utils.db_model as m
+import EMMSA.msautils.db_model as m
 from sqlalchemy.ext.sqlsoup import SqlSoup
 import sqlalchemy as sa
 from sqlalchemy import and_
